{% extends 'base.html' %}

<!-- 
  Note: See TailwindUI preview and TailwindCSS docs, they are used heavily
 -->

{% block content %}
<div class="flex items-center justify-center mt-6">
  Wow, such empty
</div>
{% endblock %}
