# Generated by Django 3.0.7 on 2020-06-30 03:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Economy',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('real_average_profit_rate', models.FloatField()),
                ('estimated_average_profit_rate', models.FloatField()),
            ],
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True)),
                ('real_price', models.FloatField()),
                ('direct_labor', models.FloatField()),
                ('direct_wages', models.FloatField()),
                ('indirect_wages', models.FloatField(default=0)),
                ('indirect_labor', models.FloatField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='Dependency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('quantity', models.FloatField()),
                ('dependency', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dependencies', to='backend.Product')),
                ('dependent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dependents', to='backend.Product')),
            ],
        ),
    ]
